==> qt5-webengine-5.12.0-1-x86_64.pkg.tar.xz: usr/include/qt/QtWebEngineCore/5.12.0/QtWebEngineCore/private/qtwebenginecore-config_p.h <==
#define QT_FEATURE_webengine_alsa 1
#define QT_FEATURE_webengine_bison 1
#define QT_FEATURE_webengine_embedded_build -1
#define QT_FEATURE_webengine_flex 1
#define QT_FEATURE_webengine_gperf 1
#define QT_FEATURE_webengine_host_pkg_config 1
#define QT_FEATURE_webengine_kerberos -1
#define QT_FEATURE_webengine_pepper_plugins 1
#define QT_FEATURE_webengine_poppler_cpp 1
#define QT_FEATURE_webengine_printing_and_pdf 1
#define QT_FEATURE_webengine_proprietary_codecs 1
#define QT_FEATURE_webengine_pulseaudio 1
#define QT_FEATURE_webengine_python2 1
#define QT_FEATURE_webengine_sanitizer -1
#define QT_FEATURE_webengine_system_dbus 1
#define QT_FEATURE_webengine_system_opus 1
#define QT_FEATURE_webengine_system_libwebp 1
#define QT_FEATURE_webengine_system_ffmpeg 1
#define QT_FEATURE_webengine_system_fontconfig 1
#define QT_FEATURE_webengine_system_freetype 1
#define QT_FEATURE_webengine_system_glib 1
#define QT_FEATURE_webengine_system_glibc 1
#define QT_FEATURE_webengine_system_gn -1
#define QT_FEATURE_webengine_system_harfbuzz 1
#define QT_FEATURE_webengine_system_icu 1
#define QT_FEATURE_webengine_system_jpeg 1
#define QT_FEATURE_webengine_system_jsoncpp 1
#define QT_FEATURE_webengine_system_khr 1
#define QT_FEATURE_webengine_system_lcms2 1
#define QT_FEATURE_webengine_system_libdrm 1
#define QT_FEATURE_webengine_system_libevent 1
#define QT_FEATURE_webengine_system_libvpx -1
#define QT_FEATURE_webengine_system_libxml2 1
#define QT_FEATURE_webengine_system_minizip 1
#define QT_FEATURE_webengine_system_ninja 1
#define QT_FEATURE_webengine_system_nss 1
#define QT_FEATURE_webengine_system_png 1
#define QT_FEATURE_webengine_system_protobuf -1
#define QT_FEATURE_webengine_system_re2 1
#define QT_FEATURE_webengine_system_snappy 1
#define QT_FEATURE_webengine_system_x11 1
#define QT_FEATURE_webengine_system_xcomposite 1
#define QT_FEATURE_webengine_system_xcursor 1
#define QT_FEATURE_webengine_system_xi 1
#define QT_FEATURE_webengine_system_xrandr 1
#define QT_FEATURE_webengine_system_xtst 1
#define QT_FEATURE_webengine_system_zlib 1
#define QT_FEATURE_webengine_testsupport -1
#define QT_FEATURE_webengine_ui_delegates 1
#define QT_FEATURE_webengine_v8_snapshot 1
#define QT_FEATURE_webengine_v8_snapshot_support 1
#define QT_FEATURE_webengine_webrtc 1
#define QT_FEATURE_webengine_win_compiler64 -1
#define QT_FEATURE_webengine_winversion -1

==> qt5-webengine-5.12.2-2-x86_64.pkg.tar.xz: usr/include/qt/QtWebEngineCore/5.12.2/QtWebEngineCore/private/qtwebenginecore-config_p.h <==
#define QT_FEATURE_webengine_alsa 1
#define QT_FEATURE_webengine_embedded_build -1
#define QT_FEATURE_webengine_arm_thumb -1
#define QT_FEATURE_webengine_bison 1
#define QT_FEATURE_webengine_flex 1
#define QT_FEATURE_webengine_gperf 1
#define QT_FEATURE_webengine_host_pkg_config 1
#define QT_FEATURE_webengine_kerberos -1
#define QT_FEATURE_webengine_pepper_plugins 1
#define QT_FEATURE_webengine_poppler_cpp 1
#define QT_FEATURE_webengine_printing_and_pdf 1
#define QT_FEATURE_webengine_proprietary_codecs 1
#define QT_FEATURE_webengine_pulseaudio 1
#define QT_FEATURE_webengine_python2 1
#define QT_FEATURE_webengine_sanitizer -1
#define QT_FEATURE_webengine_system_dbus 1
#define QT_FEATURE_webengine_system_opus 1
#define QT_FEATURE_webengine_system_libwebp 1
#define QT_FEATURE_webengine_system_ffmpeg 1
#define QT_FEATURE_webengine_system_fontconfig 1
#define QT_FEATURE_webengine_system_freetype 1
#define QT_FEATURE_webengine_system_glib 1
#define QT_FEATURE_webengine_system_glibc 1
#define QT_FEATURE_webengine_system_gn -1
#define QT_FEATURE_webengine_system_harfbuzz 1
#define QT_FEATURE_webengine_system_icu 1
#define QT_FEATURE_webengine_system_jpeg 1
#define QT_FEATURE_webengine_system_jsoncpp 1
#define QT_FEATURE_webengine_system_khr 1
#define QT_FEATURE_webengine_system_lcms2 1
#define QT_FEATURE_webengine_system_libdrm 1
#define QT_FEATURE_webengine_system_libevent 1
#define QT_FEATURE_webengine_system_libvpx 1
#define QT_FEATURE_webengine_system_libxml2 1
#define QT_FEATURE_webengine_system_minizip 1
#define QT_FEATURE_webengine_system_ninja 1
#define QT_FEATURE_webengine_system_nss 1
#define QT_FEATURE_webengine_system_png 1
#define QT_FEATURE_webengine_system_protobuf -1
#define QT_FEATURE_webengine_system_re2 1
#define QT_FEATURE_webengine_system_snappy 1
#define QT_FEATURE_webengine_system_x11 1
#define QT_FEATURE_webengine_system_xcomposite 1
#define QT_FEATURE_webengine_system_xcursor 1
#define QT_FEATURE_webengine_system_xi 1
#define QT_FEATURE_webengine_system_xtst 1
#define QT_FEATURE_webengine_system_zlib 1
#define QT_FEATURE_webengine_testsupport -1
#define QT_FEATURE_webengine_ui_delegates 1
#define QT_FEATURE_webengine_v8_snapshot 1
#define QT_FEATURE_webengine_v8_snapshot_support 1
#define QT_FEATURE_webengine_webrtc 1
#define QT_FEATURE_webengine_win_compiler64 -1
#define QT_FEATURE_webengine_winversion -1
